paging

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 29, 2024 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Paging

type Paging struct {
	PageIndex int `json:"pageIndex,omitempty"`
	PageSize  int `json:"pageSize,omitempty"`
	Total     int `json:"total,omitempty"`
}

Paging is the part of the response that contains paging info

func (*Paging) End

func (p *Paging) End() bool

End returns whether the last page has been reached or not

type Params

type Params struct {
	P  int // 1-based page number
	Ps int // Page size. Must be greater than 0 and less or equal than 500
}

Params are the params used for paging the request

Jump to