package
Version:
v0.1.2
Opens a new window with list of versions in this module.
Published: Nov 29, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Paging struct {
PageIndex int `json:"pageIndex,omitempty"`
PageSize int `json:"pageSize,omitempty"`
Total int `json:"total,omitempty"`
}
Paging is the part of the response that contains paging info
End returns whether the last page has been reached or not
type Params struct {
P int
Ps int
}
Params are the params used for paging the request
Source Files
¶
Click to show internal directories.
Click to hide internal directories.